<?php include 'header.php';?>
    <main>
      <div class="herobanner text-center bg-light-resources">
        <div class="container">
          <div
            class="bannertxt width60"
            data-aos="fade-up"
            data-aos-duration="3000"
          >
            <div class="bannerleft_line">
              <img src="./assets/images/lines.svg" />
            </div>
            <h1>Simplisync’s Security Details</h1>
            <p>
              we recognize the importance of excellent security practices. While
              we are a small team, we work hard to punch above our weight on
              security.
            </p>
            <p>
              This document covers our security practices and policies. If you
              are interested in the data we collect and store, please see
              our privacy policy.
            </p>
            <div class="banneright_line">
              <img src="./assets/images/lines2.svg" />
            </div>
          </div>
        </div>
      </div>
      <div class="data-doc py-5">
        <div class="container">
          <h3>General practices</h3>
          <ul>
            <li>
              Access to servers, source code, and third-party tools are secured
              with two-factor auth.
            </li>
            <li>
              We use strong, randomly-generated passwords that are never
              re-used.
            </li>
            <li>
              Employees and contractors are given the lowest level of access
              that allows them to get their work done. This rarely includes
              access to production systems or data.
            </li>
            <li>
              We use automatic security vulnerability detection tools to alert
              us when our dependencies have known security issues. We are
              aggressive about applying patches and deploying quickly.
            </li>
            <li>
              We don’t copy production data to external devices (like personal
              laptops).
            </li>
          </ul>
          <h3>Access control and organizational security</h3>
          <h5>Personnel</h5>
          <p>
            Our employees and contractors sign an NDA before gaining access to
            sensitive information.
          </p>
          <h5>Penetration testing</h5>
          <p>
            We had a penetration test performed in August of 2024. The
            assessment concluded that “the security posture of the Simplisync
            was found to be in line with industry’s best practices.” If you’d
            like a full copy of the results,
            <a href="mailto:sales@simplisync.ai ">send us an email.</a>&nbsp;
          </p>
          <h3>Authentication</h3>
          <p>
            At sign-up, each customer is given an invite link to share with
            their team. Each team member can use that link to set up a new
            account with their email and password. User passwords are hashed
            using bcrypt before being stored. When a user logs in, they are
            given a 20-byte authentication token, generated with the
            SecureRandom tool in the Ruby Standard Library. The token is
            invalidated after 30 days of inactivity. All further interaction
            with the API is done by providing an&nbsp;Authorization&nbsp;header
            with this token.
          </p>
          <h3>Encryption</h3>
          <h5>Definitions</h5>
          <ul>
            <li>
              <p>
                <b>Data&nbsp;-</b>Data&nbsp;- Clicks, keystrokes, drawings,
                animations, etc.
              </p>
              <p></p>
            </li>
            <li>
              <p><b>Media&nbsp;-</b>Video (webcam and screenshare) and audio</p>
            </li>
          </ul>
          <p>
            <b
              >All data and media during a 2 or 3-person pairing session are
              sent peer-to-peer (avoiding our servers) and are encrypted
              end-to-end. All data during a call with 4 or more participants are
              sent peer-to-peer. Media is sent end-to-end encrypted and relayed
              through our media servers.</b
            >
          </p>
          <p>
            When we say “end-to-end”, we mean it in the way you’d expect: your
            data and media is not (and cannot be!) decrypted by anything other
            than the clients involved in the call. Stated another way: the only
            people that can see anything that happens in a pairing session are
            its participants.
          </p>
          <p>
            Data channels in peer-to-peer connections are encrypted using
            Datagram Transport Layer Security (DTLS) version 1.2, while media
            streams are encrypted using Secure Real-time Transport Protocol
            (SRTP).
          </p>
          <p>
            When there are 4 or more participants on a call, encrypted media
            streams are relayed through our servers using SRTP. Each frame in
            the stream is encoded using AES-256 encryption. Keys are randomly
            generated by each participant and are never reused. Keys are
            exchanged using peer-to-peer data channels over DTLS. We do not
            store any user media on these servers.<b
              > Our servers never have access to the keys and cannot decode any
              media.</b
            >
          </p>
          <h5>Data flows</h5>
          <p>
            All logged-in users are connected to a signaling server using the
            WebSocket protocol.
          </p>
          <p>
            When a Simplisync client wants to initiate a call, it sends an
            “Offer” through the signaling server and identifies the recipient of
            the call. The server then pushes that message to the intended
            recipient. The user on the receiving end will be prompted with an
            incoming call and can accept or decline. If the user accepts, the
            client sends an “Answer” and the peers then negotiate an encrypted
            connection. The peers exchange keys directly through an encrypted
            tunnel. The keys are never sent in plain text.
          </p>
          <p>
            In most cases, both peers will be able to identify addressable IPs
            and ports on which to establish a peer-to-peer connection using the
            STUN protocol. Under some restrictive firewall configurations, this
            is impossible and traffic must be routed through an intermediate
            server using the TURN protocol. These servers cannot decrypt the
            contents of the data packets, and only route based on the UDP
            layer.&nbsp;Under no circumstances does video, audio, keystrokes,
            cursor movements, or clipboard data pass through our servers when
            using the TURN protocol.
          </p>
          <h5>Data retention/logging</h5>
          <p>
            Logs are stored separate from our backend infrastructure in a
            private CloudWatch area.
          </p>
          <p>
            These logs are retained for 30 days, after which they are
            permanently deleted.
          </p>
          <p>Application analytics can be permanently deleted on request.</p>
          <h5>Software development practices</h5>
          <ul>
            <li>
              Code written by any developer is signed off by at least one other
              person before committing.
            </li>
            <li>
              Code is tested in a staging environment against a QA checklist
              before deploying to production.
            </li>
            <li>
              The Simplisync client is code-signed and has the&nbsp;Hardened
              Runtime mode&nbsp;enabled (which protects against code injection,
              DLL hijacking, and process memory space tampering).
            </li>
            <li>
              The Simplisync client is automatically scanned for malware and
              notarized on every deploy.
            </li>
          </ul>
          <h5>Vulnerability detection</h5>
          <p>
            Both the client and our backend are regularly scanned for
            dependencies with known security vulnerabilities.
          </p>
          <p>Vulnerable dependencies are patched and redeployed rapidly.</p>
          <h3>FAQs</h3>
          <h5>How are keys exchanged between clients?</h5>
          <p>
            When two peers begin a call, the first step is to exchange keys for
            encrypting the communication. This happens directly between the
            peers. The exchange is encrypted with DTLS (a derivative of SSL).
            The clients use a self signed certificate (asymmetric-key) based on
            RSA to exchange the keys they will use. Thus, the exchange of keys
            is a) encrypted and b) done directly peer-to-peer. The packets never
            touch any servers under our control. We cannot intercept the
            exchange of keys and would see only encrypted data if we tried.
            Also, the code that handles this exchange is from WebRTC, which is
            open-source, frequently audited, and primarily written and
            maintained by Google’s security experts.
          </p>
          <div class="d-flex justify-content-center m-auto">
            <button class="btn demo-nav">Read More</button>
          </div>
        </div>
      </div>
    </main>
    <?php include 'footer.php';?>
